@@ -298,7 +298,29 @@
 #'   subpopulations, categories within each subpopulation, response variables,
 #'   and categories within each response variable.  Estimates are provided for
 #'   proportion and size of the population plus standard error, margin of
-#'   error, and confidence interval estimates.
+#'   error, and confidence interval estimates. The data frame contains the following
+#'   variables:
+#'   \describe{
+#'     \item{Type}{subpopulation (domain) name}
+#'     \item{Subpopulation}{subpopulation name within a domain}
+#'     \item{Response}{response variable}
+#'     \item{Stressor}{stressor variable}
+#'     \item{nResp}{sample size}
+#'     \item{Estimate}{attributable risk estimate}
+#'     \item{StdError_log}{attributable risk standard error (on the log scale)}
+#'     \item{MarginofError_log}{attributable risk margin of error (on the log scale)}
+#'     \item{LCBxxPct}{xx\% (default 95\%) lower confidence bound}
+#'     \item{UCBxxPct}{xx\% (default 95\%) upper confidence bound}
+#'     \item{WeightTotal}{sum of design weights}
+#'     \item{Count_RespPoor_StressPoor}{number of observations in the poor response and poor stressor group}
+#'     \item{Count_RespPoor_StressGood}{number of observations in the poor response and good stressor group}
+#'     \item{Count_RespGood_StressPoor}{number of observations in the good response and poor stressor group}
+#'     \item{Count_RespGood_StressGood}{number of observations in the good response and good stressor group}
+#'     \item{Prop_RespPoor_StressPoor}{weighted proportion of observations in the poor response and poor stressor group}
+#'     \item{Prop_RespPoor_StressGood}{weighted proportion of observations in the poor response and good stressor group}
+#'     \item{Prop_RespGood_StressPoor}{weighted proportion of observations in the good response and poor stressor group}
+#'     \item{Prop_RespGood_StressGood}{weighted proportion of observations in the good response and good stressor group}
+#'   }
 #'
 #' @author Tom Kincaid \email{Kincaid.Tom@@epa.gov}
 #'
@@ -726,7 +748,7 @@ attrisk_analysis <- function(dframe, vars_response, vars_stressor, response_leve
           k <- k + 1
         }
       }
-      design <- calibrate(design, make.formula(cnames), pop_totals)
+      design <- calibrate(design, make.formula(names(popsize)), pop_totals)
     }
   }
 
