@@ -249,7 +249,25 @@
 #'   subpopulations, categories within each subpopulation, response variables,
 #'   and categories within each response variable.  Estimates are provided for
 #'   proportion and total of the population plus standard error, margin of
-#'   error, and confidence interval estimates.
+#'   error, and confidence interval estimates. The data frame contains the following
+#'   variables:
+#'   \describe{
+#'     \item{Type}{subpopulation (domain) name}
+#'     \item{Subpopulation}{subpopulation name within a domain}
+#'     \item{Indicator}{response variable}
+#'     \item{Category}{category of response variable}
+#'     \item{nResp}{sample size}
+#'     \item{Estimate.P}{proportion estimate (in \%)}
+#'     \item{StdError.P}{standard error of proportion estimate}
+#'     \item{MarginofError.P}{margin of error of proportion estimate}
+#'     \item{LCBxxPct.P}{xx\% (default 95\%) lower confidence bound of proportion estimate}
+#'     \item{UCBxxPct.P}{xx\% (default 95\%) upper confidence bound of proportion estimate}
+#'     \item{Estimate.U}{total estimate}
+#'     \item{StdError.U}{standard error of total estimate}
+#'     \item{MarginofError.U}{margin of error of total estimate}
+#'     \item{LCBxxPct.U}{xx\% (default 95\%) lower confidence bound of total estimate}
+#'     \item{UCBxxPct.U}{xx\% (default 95\%) upper confidence bound of total estimate}
+#'   }
 #'
 #' @author Tom Kincaid \email{Kincaid.Tom@@epa.gov}
 #'
@@ -559,7 +577,7 @@ cat_analysis <- function(dframe, vars, subpops = NULL, siteID = NULL, weight = "
           k <- k + 1
         }
       }
-      design <- calibrate(design, make.formula(cnames), pop_totals)
+      design <- calibrate(design, make.formula(names(popsize)), pop_totals)
     }
   }
 
